@@ -2,8 +2,8 @@ setClass("SpatialPixelsDataFrame",
 	representation("SpatialPixels", data = "data.frame", coords.nrs = "numeric"),
 	contains = "SpatialPointsDataFrame",
 	validity = function(object) {
-		if (length(object@grid.index) == 0)
-			stop("grid.index should not have length zero")
+		if (length(object@grid.index) != nrow(object@data))
+			stop("grid.index should have length equal to data slot")
 		if (nrow(object@coords) != nrow(object@data))
 			stop("unequal number of objects in points and data.frame")
 		return(TRUE)
@@ -13,8 +13,6 @@ setClass("SpatialPixelsDataFrame",
 setClass("SpatialGridDataFrame",
 	representation("SpatialGrid", data = "data.frame"),
 	validity = function(object) {
-		if (length(object@grid.index) > 0)
-			stop("grid.index should have length zero")
 		if (.NumberOfCells(object@grid) != nrow(object@data))
 			stop("unequal number of objects in full grid and data slot")
 		return(TRUE)
