@@ -81,6 +81,11 @@ setMethod("over",
 			r
 		}
 )
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialPolygons"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
 setMethod("over",
 	signature(x = "SpatialPoints", y = "SpatialPolygonsDataFrame"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...) {
@@ -94,6 +99,11 @@ setMethod("over",
 			ret
 		}
 )
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialPolygonsDataFrame"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
 
 setMethod("over",
 	signature(x = "SpatialPolygons", y = "SpatialPoints"), 
@@ -106,6 +116,11 @@ setMethod("over",
 				r
 		}
 )
+setMethod("over",
+	signature(x = "SpatialPolygons", y = "SpatialGrid"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(x = x, y = as(y, "SpatialPoints"), returnList = returnList, fn = fn, ...)
+)
 setMethod("over",
 	signature(x = "SpatialPolygons", y = "SpatialPointsDataFrame"), 
 		overDFGeneric)
